################################################################################
##### Fried et al 2015, Frontiers commentary, DOI 10.3389/fpsyt.2015.00117 #####
################################################################################

library(qgraph)
library(scatterplot3d)
library(ggplot2)

setwd("C:/Users/u0097060/Dropbox/Research/My Papers/2. Commentaries/2015-FRONTIERS-Commentary Hieronymus et al/2. Frontiers/2. revision/analysis")

##### DATA PREPARATION

data<-read.csv("IDS_HAMD.csv", head=T)
data[data == -999] <- NA
data <- subset(data, select=c(age,sex,DATE.1,Hsum.1,H1.1:H17.1))
data <-na.omit(data)

data.H.0 <- subset(data, select=c(H1.1:H17.1))

### original data order
symptoms=c("01","02","03","04","05", "06","07","08","09","10", "11","12", "13","14","15", "16","17")
#1=ins1,  2=ins2,	3=ins3,	4=sad,	5=psychic anxiety,	6=appetite	7=weight	8=guilt,	9=suicide, 10=work	and interests, 11=somatic energy,	12=libido,	13=retardation,	14=agitation,	15=somatic anxiety,	16=hypochondriasis,	17=loss

#change order to fit the symptom order of hieronymus et al 2015 paper
symptoms=c("04","05","06","01","10", "12","16","02","03","07","13","14","08","09","11", "15","17")

### estimate glasso 
t0.H <- cor_auto(data.H.0)
graph<- EBICglasso(t0.H, n = nrow(data)) # estimate glasso matrix
qgraph(graph, labels=symptoms, layout="spring", vsize=5, cut=0)

### centrality plot (not used in paper)
centralityPlot(graph)

### correlations
cent<-centrality(graph)
cent.close<-cent$Closeness
# effectsize and reported means from hieronymus et al 2015 paper
effectsize<-c(0.08,0.07,0.13,0.44,0.3,-0.02,-0.06,0.26,0.22,0.23,0.16,-0.01,0.21,0.08,0.06,0.12,0.07)
mean_reported<-c(1.2,1.3,1.2,2.8,2.2,0.6,0.3,1.7,1.1,2.7,1.7,1.3,1.1,1.1,1.6,0.9,0.2)
cor.test(effectsize,cent.close) # 0.534, p=0.027
cor.test(mean_reported,effectsize) # 0.769, p=0.0003
cor.test(mean_reported,cent.close) # 0.595, p=0.012

### 3d plot
scatterplot3d(mean_reported, cent.close,effectsize, pch=16, highlight.3d=F,type="h", 
              xlab='Mean',ylab='Closeness',zlab='Effect size')


